@@ -119,6 +119,7 @@ class JSONFixture:
         traces=None,
         attachments=None,
         parameters=None,
+        properties=None,
         links=None,
         duration=None,
         failure_reason_name=None,
@@ -148,6 +149,9 @@ class JSONFixture:
         if parameters:
             json['parameters'] = parameters
 
+        if properties:
+            json['properties'] = properties
+
         if links:
             json['links'] = links
 
